Method: Net::LDAP::Filter#&

Defined in:
lib/net/ldap/filter.rb

#&(filter) ⇒ Object

operator & (“AND”) is used to conjoin two or more filters. This expression will select only entries that have an objectclass attribute AND have a mail attribute that begins with “George”:

f = Net::LDAP::Filter.pres( "objectclass" ) & Net::LDAP::Filter.eq( "mail", "George*" )


97
# File 'lib/net/ldap/filter.rb', line 97

def & filter; Filter.new :and, self, filter; end